@@ -122,6 +122,7 @@ transfer.  For example:
 
 
 """
+
 import logging
 import threading
 from os import PathLike, fspath, getpid
@@ -256,7 +257,7 @@ class TransferConfig(S3TransferConfig):
         :param max_concurrency: The maximum number of threads that will be
             making requests to perform a transfer. If ``use_threads`` is
             set to ``False``, the value provided is ignored as the transfer
-            will only ever use the main thread.
+            will only ever use the current thread.
 
         :param multipart_chunksize: The partition size of each part for a
             multipart transfer.
@@ -281,7 +282,7 @@ class TransferConfig(S3TransferConfig):
 
         :param use_threads: If True, threads will be used when performing
             S3 transfers. If False, no threads will be used in
-            performing transfers; all logic will be run in the main thread.
+            performing transfers; all logic will be run in the current thread.
 
         :param max_bandwidth: The maximum bandwidth that will be consumed
             in uploading and downloading file content. The value is an integer
@@ -325,6 +326,7 @@ class TransferConfig(S3TransferConfig):
 class S3Transfer:
     ALLOWED_DOWNLOAD_ARGS = TransferManager.ALLOWED_DOWNLOAD_ARGS
     ALLOWED_UPLOAD_ARGS = TransferManager.ALLOWED_UPLOAD_ARGS
+    ALLOWED_COPY_ARGS = TransferManager.ALLOWED_COPY_ARGS
 
     def __init__(self, client=None, config=None, osutil=None, manager=None):
         if not client and not manager:
