@@ -17,8 +17,11 @@ from tests.functional.docs import BaseDocsFunctionalTests
 
 class TestDynamoDBCustomizations(BaseDocsFunctionalTests):
     def setUp(self):
+        super().setUp()
         self.documenter = ServiceDocumenter(
-            'dynamodb', session=Session(region_name='us-east-1')
+            'dynamodb',
+            session=Session(region_name='us-east-1'),
+            root_docs_path=self.root_services_path,
         )
         self.generated_contents = self.documenter.document_service()
         self.generated_contents = self.generated_contents.decode('utf-8')
@@ -26,27 +29,40 @@ class TestDynamoDBCustomizations(BaseDocsFunctionalTests):
     def test_batch_writer_is_documented(self):
         self.assert_contains_lines_in_order(
             [
-                '.. py:class:: DynamoDB.Table(name)',
-                '  *   :py:meth:`batch_writer()`',
-                '  .. py:method:: batch_writer(overwrite_by_pkeys=None)',
+                '=========',
+                'Resources',
+                '=========',
+                'The available resources are:',
+                '  dynamodb/table/index',
             ],
             self.generated_contents,
         )
-
-    def test_document_interface_is_documented(self):
-        contents = self.get_class_document_block(
-            'DynamoDB.Table', self.generated_contents
-        )
-
-        # Take an arbitrary method that uses the customization.
-        method_contents = self.get_method_document_block('put_item', contents)
-
-        # Make sure the request syntax is as expected.
-        request_syntax_contents = self.get_request_syntax_document_block(
-            method_contents
+        self.assert_contains_lines_in_order(
+            [
+                '.. py:class:: DynamoDB.Table(name)',
+                '  batch_writer',
+            ],
+            self.get_nested_file_contents('dynamodb', 'table', 'index'),
         )
         self.assert_contains_lines_in_order(
             [
+                '************\nbatch_writer\n************',
+                '.. py:method:: DynamoDB.Table.batch_writer(overwrite_by_pkeys=None)',
+            ],
+            self.get_nested_file_contents('dynamodb', 'table', 'batch_writer'),
+        )
+
+    def test_document_interface_is_documented(self):
+        put_item_content = self.get_nested_file_contents(
+            'dynamodb', 'table', 'put_item'
+        )
+        self.assert_contains_lines_in_order(
+            [
+                '********',
+                'put_item',
+                '********',
+                '.. py:method:: DynamoDB.Table.put_item(**kwargs)',
+                # Make sure the request syntax is as expected.
                 'response = table.put_item(',
                 'Item={',
                 (
@@ -68,16 +84,16 @@ class TestDynamoDBCustomizations(BaseDocsFunctionalTests):
                     '|True|None|set([\'string\'])|set([123])|'
                     'set([Binary(b\'bytes\')])|[]|{},'
                 ),
-            ],
-            request_syntax_contents,
-        )
-
-        # Make sure the response syntax is as expected.
-        response_syntax_contents = self.get_response_syntax_document_block(
-            method_contents
-        )
-        self.assert_contains_lines_in_order(
-            [
+                # Make sure the request parameter is documented correctly.
+                ':type Item: dict',
+                ':param Item: **[REQUIRED]**',
+                '- *(string) --*',
+                (
+                    '- *(valid DynamoDB type) -- *- The value of the '
+                    'attribute. The valid value types are listed in the '
+                    ':ref:`DynamoDB Reference Guide<ref_valid_dynamodb_types>`.'
+                ),
+                # Make sure the response syntax is as expected.
                 '{',
                 '\'Attributes\': {',
                 (
@@ -86,69 +102,29 @@ class TestDynamoDBCustomizations(BaseDocsFunctionalTests):
                     'set([123])|set([Binary(b\'bytes\')])|[]|{}'
                 ),
                 '},',
-            ],
-            response_syntax_contents,
-        )
-
-        # Make sure the request parameter is documented correctly.
-        request_param_contents = self.get_request_parameter_document_block(
-            'Item', method_contents
-        )
-        self.assert_contains_lines_in_order(
-            [
-                ':type Item: dict',
-                ':param Item: **[REQUIRED]**',
-                '- *(string) --*',
-                (
-                    '- *(valid DynamoDB type) --* - The value of the '
-                    'attribute. The valid value types are listed in the '
-                    ':ref:`DynamoDB Reference Guide<ref_valid_dynamodb_types>`.'
-                ),
-            ],
-            request_param_contents,
-        )
-
-        # Make sure the response parameter is documented correctly.
-        response_param_contents = self.get_response_parameter_document_block(
-            'Attributes', method_contents
-        )
-        self.assert_contains_lines_in_order(
-            [
+                # Make sure the response parameter is documented correctly.
                 '- **Attributes** *(dict) --*',
                 '- *(string) --*',
                 (
-                    '- *(valid DynamoDB type) --* - The value of '
+                    '- *(valid DynamoDB type) -- *- The value of '
                     'the attribute. The valid value types are listed in the '
                     ':ref:`DynamoDB Reference Guide<ref_valid_dynamodb_types>`.'
                 ),
             ],
-            response_param_contents,
+            put_item_content,
         )
 
     def test_conditions_is_documented(self):
-        contents = self.get_class_document_block(
-            'DynamoDB.Table', self.generated_contents
-        )
-
-        # Take an arbitrary method that uses the customization.
-        method_contents = self.get_method_document_block('query', contents)
-
-        # Make sure the request syntax is as expected.
-        request_syntax_contents = self.get_request_syntax_document_block(
-            method_contents
+        query_contents = self.get_nested_file_contents(
+            'dynamodb', 'table', 'query'
         )
         self.assert_contains_lines_in_order(
             [
+                # Make sure the request syntax is as expected.
                 'response = table.query(',
-                ('FilterExpression=Attr(\'myattribute\').' 'eq(\'myvalue\'),'),
-                ('KeyConditionExpression=Key(\'mykey\')' '.eq(\'myvalue\'),'),
-            ],
-            request_syntax_contents,
-        )
-
-        # Make sure the request parameter is documented correctly.
-        self.assert_contains_lines_in_order(
-            [
+                ('FilterExpression=Attr(\'myattribute\').eq(\'myvalue\'),'),
+                ('KeyConditionExpression=Key(\'mykey\').eq(\'myvalue\'),'),
+                # Make sure the request parameter is documented correctly.
                 (
                     ':type FilterExpression: condition from '
                     ':py:class:`boto3.dynamodb.conditions.Attr` method'
@@ -168,5 +144,5 @@ class TestDynamoDBCustomizations(BaseDocsFunctionalTests):
                     ':ref:`DynamoDB Reference Guide<ref_dynamodb_conditions>`.'
                 ),
             ],
-            method_contents,
+            query_contents,
         )
