@@ -10,11 +10,14 @@
 # distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
+import gzip
+import io
+
 import pytest
-from botocore.compat import six
 from botocore.exceptions import ClientError
 
 from boto3.s3 import inject
+from boto3.s3.transfer import TransferConfig
 from tests import mock, unittest
 
 
@@ -158,7 +161,7 @@ class TestBucketTransferMethods(unittest.TestCase):
         )
 
     def test_upload_fileobj(self):
-        fileobj = six.BytesIO(b'foo')
+        fileobj = io.BytesIO(b'foo')
         inject.bucket_upload_fileobj(self.bucket, Key='key', Fileobj=fileobj)
         self.bucket.meta.client.upload_fileobj.assert_called_with(
             Bucket=self.bucket.name,
@@ -170,7 +173,7 @@ class TestBucketTransferMethods(unittest.TestCase):
         )
 
     def test_download_fileobj(self):
-        obj = six.BytesIO()
+        obj = io.BytesIO()
         inject.bucket_download_fileobj(self.bucket, Key='key', Fileobj=obj)
         self.bucket.meta.client.download_fileobj.assert_called_with(
             Bucket=self.bucket.name,
@@ -222,7 +225,7 @@ class TestObjectTransferMethods(unittest.TestCase):
         )
 
     def test_upload_fileobj(self):
-        fileobj = six.BytesIO(b'foo')
+        fileobj = io.BytesIO(b'foo')
         inject.object_upload_fileobj(self.obj, Fileobj=fileobj)
         self.obj.meta.client.upload_fileobj.assert_called_with(
             Bucket=self.obj.bucket_name,
@@ -234,7 +237,7 @@ class TestObjectTransferMethods(unittest.TestCase):
         )
 
     def test_download_fileobj(self):
-        fileobj = six.BytesIO()
+        fileobj = io.BytesIO()
         inject.object_download_fileobj(self.obj, Fileobj=fileobj)
         self.obj.meta.client.download_fileobj.assert_called_with(
             Bucket=self.obj.bucket_name,
@@ -262,3 +265,31 @@ class TestObejctSummaryLoad(unittest.TestCase):
         self.head_object_response.pop('ContentLength')
         inject.object_summary_load(self.resource)
         assert self.resource.meta.data == {'ETag': 'my-etag'}
+
+
+def test_disable_threading_if_append_mode(caplog, tmp_path):
+    config = TransferConfig(use_threads=True)
+    with open(tmp_path / 'myfile', 'ab') as f:
+        inject.disable_threading_if_append_mode(config, f)
+    assert config.use_threads is False
+    assert 'A single thread will be used' in caplog.text
+
+
+def test_threading_not_disabled_if_not_append_mode(caplog, tmp_path):
+    config = TransferConfig(use_threads=True)
+    with open(tmp_path / 'myfile', 'wb') as f:
+        inject.disable_threading_if_append_mode(config, f)
+    assert config.use_threads is True
+    assert 'A single thread will be used' not in caplog.text
+
+
+def test_threading_not_disabled_if_mode_non_string(caplog, tmp_path):
+    config = TransferConfig(use_threads=True)
+    with gzip.open(tmp_path / 'myfile', 'wb') as f:
+        # In Python 3.13, gzip started assigning strings
+        # instead of integers for mode. Explicitly set
+        # mode to an integer to ensure we test the right behavior.
+        f.mode = 2
+        inject.disable_threading_if_append_mode(config, f)
+    assert config.use_threads is True
+    assert 'A single thread will be used' not in caplog.text
